@@ -75,13 +75,13 @@ urlpatterns = patterns('',
 
     url(r'^account/projects/$', projects.project_list, name='sentry-project-list'),
     url(r'^account/projects/new/$', projects.new_project, name='sentry-new-project'),
-    url(r'^account/projects/(?P<project_id>\d+)/edit/$', projects.manage_project,
+    url(r'^account/projects/(?P<project_id>[\w_-]+)/edit/$', projects.manage_project,
         name='sentry-manage-project'),
-    url(r'^account/projects/(?P<project_id>\d+)/plugins/$', projects.manage_plugins,
+    url(r'^account/projects/(?P<project_id>[\w_-]+)/plugins/$', projects.manage_plugins,
         name='sentry-manage-project-plugins'),
-    url(r'^account/projects/(?P<project_id>\d+)/plugins/(?P<slug>[\w_-]+)/$', projects.configure_project_plugin,
+    url(r'^account/projects/(?P<project_id>[\w_-]+)/plugins/(?P<slug>[\w_-]+)/$', projects.configure_project_plugin,
         name='sentry-configure-project-plugin'),
-    url(r'^account/projects/(?P<project_id>\d+)/remove/$', projects.remove_project,
+    url(r'^account/projects/(?P<project_id>[\w_-]+)/remove/$', projects.remove_project,
         name='sentry-remove-project'),
 
     # Global
@@ -109,29 +109,29 @@ urlpatterns = patterns('',
 
     url(r'^api/store/$', api.store, name='sentry-api-store'),
     url(r'^api/notification/$', api.notification, name='sentry-api-notification'),
-    url(r'^api/(?P<project_id>\d+)/poll/$', api.poll, name='sentry-api-poll'),
-    url(r'^api/(?P<project_id>\d+)/resolve/$', api.resolve, name='sentry-api-resolve'),
-    url(r'^api/(?P<project_id>\d+)/bookmark/$', api.bookmark, name='sentry-api-bookmark'),
-    url(r'^api/(?P<project_id>\d+)/clear/$', api.clear, name='sentry-api-clear'),
-    url(r'^api/(?P<project_id>\d+)/chart/$', api.chart, name='sentry-api-chart'),
+    url(r'^api/(?P<project_id>[\w_-]+)/poll/$', api.poll, name='sentry-api-poll'),
+    url(r'^api/(?P<project_id>[\w_-]+)/resolve/$', api.resolve, name='sentry-api-resolve'),
+    url(r'^api/(?P<project_id>[\w_-]+)/bookmark/$', api.bookmark, name='sentry-api-bookmark'),
+    url(r'^api/(?P<project_id>[\w_-]+)/clear/$', api.clear, name='sentry-api-clear'),
+    url(r'^api/(?P<project_id>[\w_-]+)/chart/$', api.chart, name='sentry-api-chart'),
 
     # Project specific
 
-    # url(r'^(?P<project_id>\d+)/docs/$', groups.search, name='sentry-search'),
-    url(r'^(?P<project_id>\d+)/docs/(?P<platform>%s)/$' % ('|'.join(re.escape(r) for r in docs.PLATFORM_LIST),), docs.client_guide,
+    # url(r'^(?P<project_id>[\w_-]+)/docs/$', groups.search, name='sentry-search'),
+    url(r'^(?P<project_id>[\w_-]+)/docs/(?P<platform>%s)/$' % ('|'.join(re.escape(r) for r in docs.PLATFORM_LIST),), docs.client_guide,
         name='sentry-docs-client'),
 
-    url(r'^(?P<project_id>\d+)/group/(?P<group_id>\d+)/$', groups.group, name='sentry-group'),
-    url(r'^(?P<project_id>\d+)/group/(?P<group_id>\d+)/json/$', groups.group_json, name='sentry-group-json'),
-    url(r'^(?P<project_id>\d+)/group/(?P<group_id>\d+)/events/$', groups.group_event_list, name='sentry-group-events'),
-    url(r'^(?P<project_id>\d+)/group/(?P<group_id>\d+)/events/(?P<event_id>\d+)/$', groups.group_event_details, name='sentry-group-event'),
-    url(r'^(?P<project_id>\d+)/group/(?P<group_id>\d+)/actions/(?P<slug>[\w_-]+)/', groups.group_plugin_action, name='sentry-group-plugin-action'),
+    url(r'^(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/$', groups.group, name='sentry-group'),
+    url(r'^(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/json/$', groups.group_json, name='sentry-group-json'),
+    url(r'^(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/$', groups.group_event_list, name='sentry-group-events'),
+    url(r'^(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/(?P<event_id>\d+)/$', groups.group_event_details, name='sentry-group-event'),
+    url(r'^(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/actions/(?P<slug>[\w_-]+)/', groups.group_plugin_action, name='sentry-group-plugin-action'),
 
-    url(r'^(?P<project_id>\d+)/events/$', events.event_list, name='sentry-events'),
-    url(r'^(?P<project_id>\d+)/events/(?P<event_id>\d+)/replay/$', events.replay_event, name='sentry-replay'),
+    url(r'^(?P<project_id>[\w_-]+)/events/$', events.event_list, name='sentry-events'),
+    url(r'^(?P<project_id>[\w_-]+)/events/(?P<event_id>\d+)/replay/$', events.replay_event, name='sentry-replay'),
 
-    url(r'^(?P<project_id>\d+)/search/$', groups.search, name='sentry-search'),
+    url(r'^(?P<project_id>[\w_-]+)/search/$', groups.search, name='sentry-search'),
 
-    url(r'^(?P<project_id>\d+)/view/(?P<view_id>\d+)/$', groups.group_list, name='sentry'),
-    url(r'^(?P<project_id>\d+)/$', groups.group_list, name='sentry'),
+    url(r'^(?P<project_id>[\w_-]+)/view/(?P<view_id>\d+)/$', groups.group_list, name='sentry'),
+    url(r'^(?P<project_id>[\w_-]+)/$', groups.group_list, name='sentry'),
 )
